View source: R/profileCI-logLikFn.R
| logLikFn | R Documentation |
This is a generic function for calculating a log-likelihood for an object at input parameter values.
logLikFn(object, pars, ...)
## S3 method for class 'glm'
logLikFn(object, pars, ...)
object |
A fitted model object. |
pars |
A numeric vector of parameters of the model. |
... |
Further arguments. |
This generic function has been created to enable a function that
calculates the log-likelihood for a parametric model at a given set of
parameter values in pars to be available to the function profileCI.
A numeric scalar. The value of the log-likelihood function for the
fitted model object object for parameter values pars.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.