This is a generic function for calculating a log-likelihood for an object at input parameter values.
logLikFn(object, pars, ...)# S3 method for glm
logLikFn(object, pars, ...)
# S3 method for nls
logLikFn(object, pars, ...)
A numeric scalar. The value of the log-likelihood function for the
fitted model object object for parameter values pars.
The logLikFn.glm generic is specifically for the unweighted Poisson
log-linear GLM case.
The logLikFn.nls generic is more general and should work for all
model objects returned by stats::nls.
A fitted model object.
A numeric vector of parameters of the model.
Further arguments. None are used in the logLikFn.glm and
logLikFn.nls generics.
This generic function has been created to enable a function that
calculates the log-likelihood for a parametric model at a given set of
parameter values in pars to be available to the function profileCI.
profileCI, stats::glm, stats::nls.